@@ -626,7 +626,7 @@
     result
 }
 
-##' Are variables in a data frame factors?
+##' Vectorised checks for variable types
 ##'
 ##' @param df a data frame or tibble
 `is_factor_var` <- function(df) {
@@ -634,6 +634,12 @@
     result
 }
 
+##' @rdname is_factor_var
+`is_numeric_var` <- function(df) {
+    result <- vapply(df, is.numeric, logical(1L))
+    result
+}
+
 ##' Shift numeric values in a data frame by an amount `eps`
 ##'
 ##' @param df a data frame or tibble.
